@@ -1,3 +1,19 @@
+################################################################################
+# Copyright IBM Corporate 2022
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+################################################################################
+
 from pathlib import Path
 from typing import Optional, Union
 import networkx as nx
@@ -40,11 +56,12 @@ class Cargo:
                 fragment='')
         )
         if use_dgi:
+            neo4j_uname, neo4j_passw = dgi_neo4j_auth.split(":")
             self.graph: nx.MultiDiGraph = self.dgi2networkx(
-                url, dgi_neo4j_auth)
+                url, neo4j_uname, neo4j_passw)
         Cargo.verbose = verbose
 
-    def dgi2networkx(self, neo4j_url: str, dgi_neo4j_auth: str) -> nx.MultiDiGraph:
+    def dgi2networkx(self, neo4j_url: str, dgi_neo4j_uname: str, dgi_neo4j_passw: str) -> nx.MultiDiGraph:
         """Convert the graph in DGI's neo4j to a local networkx instance.
 
         Args:
@@ -56,7 +73,7 @@ class Cargo:
         """
         Log.warn(
             "Loading graphs from Neo4j database. This could take a few minutes to complete.")
-        graph = Graph(neo4j_url, auth=tuple(dgi_neo4j_auth.split(":")))
+        graph = Graph(neo4j_url, auth=(dgi_neo4j_uname, dgi_neo4j_passw))
         # For now, we'll ignore transactional call trace
         # TODO: Add context sensitivity to transactional call trace and then use that to partition.
         cursor = graph.run(
